@@ -23,38 +23,66 @@
 #'   before starting?
 #'
 #' @examples
-#' devtools::create("tempkg")
+#' usethis::create_package("tempkg", open = FALSE)
 #' setwd("tempkg")
 #' file.copy(system.file("extdata", "detect.R", package = "exampletestr"), "R")
-#' devtools::document()
 #' exampletestr::extract_examples("detect")
 #' setwd("..")
 #' filesstrings::dir.remove("tempkg")
 #'
 #' @return A list of character vectors.
-#' @export
+#' @noRd
 extract_examples <- function(r_file_name, pkg_dir = ".", document = TRUE) {
   checkmate::assert_directory_exists(pkg_dir)
-  if (stringr::str_detect(r_file_name, "/"))
+  if (stringr::str_detect(r_file_name, "/")) {
     r_file_name <- filesstrings::str_after_last(r_file_name, "/")
+  }
   cwd <- getwd()
   on.exit(setwd(cwd))
   setwd(pkg_dir)
   pkg_root_dir <- try(rprojroot::find_root("DESCRIPTION"), silent = TRUE)
   if (inherits(pkg_root_dir, "try-error")) {
-    stop("Your package has no DESCRIPTION file.", "\n",
-         "    * Every R package must have a DESCRIPTION file ",
-         "in the root directory. ",
-         "Perhaps you specified the wrong `pkg_dir` in the argument to ",
-         "`extract_examples()`? The default is the current directory.")
+    custom_stop(
+      "Your package has no DESCRIPTION file.",
+      "
+      Every R package must have a DESCRIPTION file in the root directory.
+      Perhaps you specified the wrong {code('pkg_dir')} in the argument to
+      {code('extract_examples()')}? The default is the current directory.
+      "
+    )
   }
   setwd(pkg_root_dir)
   if (document) {
-    message("Running devtools::document() . . .")
+    message("Running ", code("devtools::document()"), " . . .")
     invisible(utils::capture.output(devtools::document()))
   }
-  r_file_name <- stringr::str_c(rprojroot::find_package_root_file("R"),
-                                "/", r_file_name) %>%
+  if (!dir.exists(rprojroot::find_package_root_file("man"))) {
+    custom_stop("The package has no {code('man/')} folder.",
+                "
+                {code('exampletestr')} looks in the {code('man/')} folder for
+                function examples and cannot function without a
+                {code('man/')} folder.
+                ", "
+                Try running your test shell creating function again with
+                {code('document = TRUE')}; this will create a {code('man/')}
+                folder.
+                ")
+  }
+  if (!length(dir(rprojroot::find_package_root_file("man"),
+                  pattern = "\\.Rd$"))) {
+    custom_stop("
+                The package's {code('man/')} folder has no
+                {code('.Rd')} files.
+                ",
+                "
+                {code('exampletestr')} looks in the {code('man/')} folder for
+                {code('.Rd')} files and cannot function without them.
+                ")
+  }
+  r_file_name <- stringr::str_c(
+    rprojroot::find_package_root_file("R"),
+    "/", r_file_name
+  ) %>%
     filesstrings::give_ext("R")
   checkmate::assert_file_exists(r_file_name)
   r_file_lines_quotes_gone <- readr::read_lines(r_file_name) %>%
@@ -65,14 +93,18 @@ extract_examples <- function(r_file_name, pkg_dir = ".", document = TRUE) {
     purrr::map(readr::read_lines) %>%
     unlist() %>%
     filesstrings::remove_quoted()
-  r_file_funs <- stringr::str_match(r_file_lines_quotes_gone,
-                                    "(^[^ ]*) <- function\\(")[, 2] %>%
+  r_file_funs <- stringr::str_match(
+    r_file_lines_quotes_gone,
+    "(^[^ ]*)\\s*(<-|=)\\s*function\\("
+  )[, 2] %>%
     stats::na.omit()
   rd_file_paths <- list.files(rprojroot::find_package_root_file("man"),
-                              pattern = "\\.Rd$") %>%
+    pattern = "\\.Rd$"
+  ) %>%
     paste0(rprojroot::find_package_root_file("man"), "/", .)
   rd_file_lines <- purrr::map(rd_file_paths, readr::read_lines)
-  rd_file_short_names <- rd_file_paths %>% filesstrings::before_last_dot() %>%
+  rd_file_short_names <- rd_file_paths %>%
+    filesstrings::before_last_dot() %>%
     filesstrings::str_after_last("/")
   names(rd_file_lines) <- rd_file_short_names
   documented_funs_in_alias_tags <- unlist(rd_file_lines) %>%
@@ -89,10 +121,12 @@ extract_examples <- function(r_file_name, pkg_dir = ".", document = TRUE) {
         i <- i + 1
       as.integer(i)
     }) %>%
-    purrr::map_chr(~ rd_file_short_names[.])
+    purrr::map_chr(~rd_file_short_names[.])
   wanted_rds <- unique(documented_where)
-  wanted_rd_paths <- paste0(rprojroot::find_package_root_file("man/"), "/",
-                            filesstrings::give_ext(wanted_rds, "Rd"))
+  wanted_rd_paths <- paste0(
+    rprojroot::find_package_root_file("man/"), "/",
+    filesstrings::give_ext(wanted_rds, "Rd")
+  )
   examples <- purrr::map(wanted_rd_paths, extract_examples_rd)
   names(examples) <- wanted_rds
   ls_exs <- lengths(examples)
@@ -123,17 +157,16 @@ extract_examples <- function(r_file_name, pkg_dir = ".", document = TRUE) {
 #'   testing all of the calls in the example block.
 #'
 #' @examples
-#' devtools::create("tempkg")
+#' usethis::create_package("tempkg", open = FALSE)
 #' setwd("tempkg")
 #' file.copy(system.file("extdata", "detect.R", package = "exampletestr"), "R")
-#' devtools::document()
 #' make_test_shell(extract_examples("detect")[[1]])
 #' make_test_shell(extract_examples("detect")[[1]],
 #'                 desc = "xyz", e_e = FALSE)
 #' setwd("..")
 #' filesstrings::dir.remove("tempkg")
 #'
-#' @export
+#' @noRd
 make_test_shell <- function(example_block, desc = "", e_e = TRUE) {
   checkmate::assert_character(example_block)
   if (!length(example_block)) return(character(0))
@@ -142,43 +175,51 @@ make_test_shell <- function(example_block, desc = "", e_e = TRUE) {
     for_checking <- expressions %>%
       purrr::map(filesstrings::remove_quoted) %>%
       purrr::map(stringr::str_replace_all, " ", "")
-    leave_alone <- purrr::map_lgl(for_checking,
-      ~ any(stringr::str_detect(., paste0("(?:<-|^stop\\(|^warning",
-                                          "\\(|^#|^setwd\\(|^library\\(|",
-                                          "^plot\\(|^ggplot\\(|^print",
-                                          "\\(|^set\\.seed\\()"))))
-    inside_test_that <- purrr::map2(leave_alone, expressions,
-      ~ if (.x) {
-          .y
-        } else {
-          construct_expect_equal(.y)
-        }
+    leave_alone <- purrr::map_lgl(
+      for_checking,
+      ~any(stringr::str_detect(., paste0(
+        "(?:<-|^stop\\(|^warning",
+        "\\(|^#|^setwd\\(|^library\\(|",
+        "^plot\\(|^ggplot\\(|^print",
+        "\\(|^set\\.seed\\()"
+      )))
+    )
+    inside_test_that <- purrr::map2(
+      leave_alone, expressions,
+      ~if (.x) {
+        .y
+      } else {
+        construct_expect_equal(.y)
+      }
     ) %>%
       unlist()
   } else {
     inside_test_that <- unlist(expressions)
   }
-  c(paste0("test_that(\"", desc, "\", {"),
-    paste(" ", inside_test_that),  # this will prepend two spaces
-    "})")
+  c(
+    paste0("test_that(\"", desc, "\", {"),
+    paste(" ", inside_test_that), # this will prepend two spaces
+    "})"
+  )
 }
 
 #' Create test shells.
 #'
 #' \itemize{\item For a given function `fun()` in a package,
-#' [make_test_shell_fun()][test-shells] checks if there are examples for that
-#' function detailed in the `man/` directory (in a `.Rd` file) and if so creates
-#' a shell (skeleton) of a [testthat::test_that()] test based on those examples
-#' via [make_test_shell()][test-shells]. The created shell is then written to a
-#' corresponding file `test-fun-examples.R` in `tests/testthat`. \item For a
-#' given file `x.R` in the `R/` directory of a package, for each function
-#' defined in that `.R` file, [make_tests_shells_file()][test-shells] checks if
-#' there are examples for that function detailed in the `man/` directory (in a
-#' `.Rd` file) and if so creates a shell (skeleton) of a [testthat::test_that()]
-#' test based on those examples via [make_test_shell()][test-shells]. The
-#' created shells are then written to a corresponding file `test-x-examples.R`
-#' in `tests/testthat`. \item [make_test_shells_pkg()][test-shells] runs
-#' [make_test_shells_file()][test-shells] on every `.R` file in the `R/`
+#' [make_test_shell_fun()][make-test-shells] checks if there are examples for
+#' that function detailed in the `man/` directory (in a `.Rd` file) and if so
+#' creates a shell (skeleton) of a [testthat::test_that()] test based on those
+#' examples via [make_test_shell()][make-test-shells]. The created shell is then
+#' written to a corresponding file `test-fun-examples.R` in `tests/testthat`.
+#' \item For a given file `x.R` in the `R/` directory of a package, for each
+#' function defined in that `.R` file, [make_tests_shells_file()][make-test-shells]
+#' checks if there are examples for that function detailed in the `man/`
+#' directory (in a `.Rd` file) and if so creates a shell (skeleton) of a
+#' [testthat::test_that()] test based on those examples via
+#' [make_test_shell()][make-test-shells]. The created shells are then written to a
+#' corresponding file `test-x-examples.R` in `tests/testthat`. \item
+#' [make_test_shells_pkg()][make-test-shells] runs
+#' [make_test_shells_file()][make-test-shells] on every `.R` file in the `R/`
 #' directory of a package.}
 #'
 #' @param r_file_name The name of the `.R` file within `R/`. There's no need to
@@ -194,25 +235,29 @@ make_test_shell <- function(example_block, desc = "", e_e = TRUE) {
 #' @param e_e Set this to `FALSE` to prevent anything from being put in the
 #'   shell of an `expect_equal()` statement.
 #' @param open Open the created test file in your editor after it is created?
-#' @inheritParams extract_examples
+#' @param document Run [devtools::document()] to update package documentation
+#'   before starting?
 #'
 #' @return The shell of the test file is written into tests/testthat. It has the
 #'   same name as the .R file it was created from except it has "test_" tacked
 #'   onto the front.
-#' @examples
-#' devtools::create("tempkg")
-#' setwd("tempkg")
-#' file.copy(system.file("extdata", "detect.R", package = "exampletestr"), "R")
-#' make_test_shell_fun("str_detect()", document = TRUE, open = FALSE)
-#' make_tests_shells_file("detect", document = FALSE, open = FALSE)
-#' make_tests_shells_pkg(overwrite = TRUE, document = FALSE)
-#' setwd("..")
-#' filesstrings::dir.remove("tempkg")
 #'
-#' @name test-shells
+#' @examples
+#' usethis::create_package(tempdir(), open = FALSE)
+#' file.copy(system.file("extdata", c("detect.R", "match.R"),
+#'                       package = "exampletestr"),
+#'           paste0(tempdir(), "/R"))
+#' make_test_shell_fun("str_detect()", document = TRUE, open = FALSE,
+#'                     pkg_dir = tempdir())
+#' make_tests_shells_file("detect", document = FALSE, open = FALSE,
+#'                        pkg_dir = tempdir())
+#' make_tests_shells_pkg(overwrite = TRUE, document = FALSE,
+#'                       pkg_dir = tempdir())
+#'
+#' @name make-test-shells
 NULL
 
-#' @rdname test-shells
+#' @rdname make-test-shells
 #' @export
 make_test_shell_fun <- function(fun, pkg_dir = ".",
                                 overwrite = FALSE, e_e = TRUE,
@@ -224,23 +269,25 @@ make_test_shell_fun <- function(fun, pkg_dir = ".",
   setwd(pkg_dir)
   fun %<>% stringr::str_trim()
   if (stringr::str_detect(fun, stringr::coll("("))) {
-    if (filesstrings::str_elem(fun, 1) == "(") {
-      stop("The function `fun` cannot start with a parenthesis.")
+    if (filesstrings::str_elem(fun, 1) %in% c("(", ")")) {
+      custom_stop("The function {code('fun')} cannot start with a parenthesis.")
     }
     fun %<>% stringr::str_extract("^.*\\(") %>%
       stringr::str_sub(end = -2)
   }
   pkg_root_dir <- try(rprojroot::find_root("DESCRIPTION"), silent = TRUE)
   if (inherits(pkg_root_dir, "try-error")) {
-    stop("Your package has no DESCRIPTION file.", "\n",
-         "    * Every R package must have a DESCRIPTION file ",
-         "in the root directory. ",
-         "Perhaps you specified the wrong `pkg_dir` in the argument to ",
-         "`extract_examples()`? The default is the current directory.")
+    custom_stop("Your package has no DESCRIPTION file.",
+      "
+      Every R package must have a DESCRIPTION file in the root directory.
+      Perhaps you specified the wrong {code('pkg_dir')} in the argument to
+      {code('extract_examples()')}? The default is the current directory.
+      "
+    )
   }
   setwd(pkg_root_dir)
   if (document) {
-    message("Running devtools::document() . . .")
+    message("Running ", code("devtools::document()"), " . . .")
     invisible(utils::capture.output(devtools::document()))
   }
   examples <- list.files(rprojroot::find_package_root_file("R")) %>%
@@ -248,44 +295,82 @@ make_test_shell_fun <- function(fun, pkg_dir = ".",
     purrr::reduce(c)
   available_funs <- names(examples)
   fun_index <- fun
-  if (! fun %in% available_funs) {
+  if (!fun %in% available_funs) {
     fun_found <- FALSE
     escaped_fun <- ore::ore.escape(fun)
     for (i in seq_along(examples)) {
-      if (any(stringr::str_detect(examples[[i]],
-                                  paste0("### Aliases: ", ".*",
-                                         escaped_fun)))) {
+      if (any(stringr::str_detect(
+        examples[[i]],
+        paste0(
+          "### Aliases: ", ".*",
+          escaped_fun
+        )
+      ))) {
         fun_index <- i
         fun_found <- TRUE
         break
       }
     }
     if (!fun_found) {
-      stop("Could not find documented function `", fun, "()`.", "\n", "    ",
-           "* Make sure it's documented in the man/ folder of your package.")
+      if (is_documented(fun)) {
+        custom_stop(
+          "
+          The function {code(stringr::str_c(fun, '()'))} is documented but
+          has no accompanying examples.
+          ", "
+          {code('make_test_shell_fun()')} only works on functions with examples.
+          ")
+      }
+      custom_stop(
+        "
+        Could not find a documented function called
+        {code(stringr::str_c(fun, '()'))}.
+        ", "
+        Make sure it's documented in the {code('man/')} folder of your package.
+        "
+      )
     }
   }
-  examples %<>% {.[[fun_index]]}
+  examples %<>% {
+    .[[fun_index]]
+  }
   test_shell <- make_test_shell(examples, paste0("`", fun, "()` works"),
-                                e_e = e_e)
+    e_e = e_e
+  )
   context <- paste0("context(\"`", fun, "()`\")")
   combined <- c(context, "", test_shell)
-  test_file_name <- paste0(rprojroot::find_package_root_file("tests"),
-                           "/testthat/test-", fun, "-examples") %>%
+  test_file_name <- paste0(
+    rprojroot::find_package_root_file("tests"),
+    "/testthat/test-", fun, "-examples"
+  ) %>%
     filesstrings::give_ext("R")
   if (!overwrite && file.exists(test_file_name)) {
-    stop ("Stopping as to proceed would be to overwrite an existing test file:",
-          " '", paste0("test_", test_file_name), "'. ", "\n",
-          "    * To proceed, rerun with overwrite = TRUE.")
+    custom_stop(
+      "
+      Stopping as to proceed would be to overwrite an existing test file:
+      {code(test_file_name)}
+      ", "
+      To proceed with overwriting, rerun with {code('overwrite = TRUE')}.
+      "
+    )
+  }
+  if (!dir.exists(rprojroot::find_package_root_file("tests/testthat"))) {
+    usethis::use_testthat()
   }
-  if (!dir.exists(rprojroot::find_package_root_file("tests/testthat")))
-    devtools::use_testthat()
   readr::write_lines(combined, test_file_name)
+  grey_test_file_name <- test_file_name %>%
+    fs::path_rel(rprojroot::find_package_root_file()) %>%
+    code()
+  bulletize("Wrote {grey_test_file_name}.", done_bullet()) %>%
+    cat_line()
   if (open) file.edit(test_file_name)
+  bulletize("Complete the unit tests in {grey_test_file_name}.",
+            todo_bullet()) %>%
+    cat_line()
   invisible(combined)
 }
 
-#' @rdname test-shells
+#' @rdname make-test-shells
 #' @export
 make_tests_shells_file <- function(r_file_name, pkg_dir = ".",
                                    overwrite = FALSE, e_e = TRUE,
@@ -297,32 +382,39 @@ make_tests_shells_file <- function(r_file_name, pkg_dir = ".",
   setwd(pkg_dir)
   pkg_root_dir <- try(rprojroot::find_root("DESCRIPTION"), silent = TRUE)
   if (inherits(pkg_root_dir, "try-error")) {
-    stop("Your package has no DESCRIPTION file.", "\n",
-         "    * Every R package must have a DESCRIPTION file ",
-         "in the root directory. ",
-         "Perhaps you specified the wrong `pkg_dir` in the argument to ",
-         "`extract_examples()`? The default is the current directory.")
+    stop(
+      "Your package has no DESCRIPTION file.", "\n",
+      "    * Every R package must have a DESCRIPTION file ",
+      "in the root directory. ",
+      "Perhaps you specified the wrong `pkg_dir` in the argument to ",
+      "`extract_examples()`? The default is the current directory."
+    )
   }
   setwd(pkg_root_dir)
   if (document) {
-    message("Running devtools::document() . . .")
+    message("Running ", code("devtools::document()"), " . . .")
     invisible(utils::capture.output(devtools::document()))
   }
-  if (stringr::str_detect(r_file_name, "/"))
+  if (stringr::str_detect(r_file_name, "/")) {
     r_file_name <- filesstrings::str_after_last(r_file_name, "/")
+  }
   r_file_name <- filesstrings::give_ext(r_file_name, "R")
   exampless <- extract_examples(r_file_name, pkg_dir = ".", document = FALSE)
-  not_making_message <- paste0("No examples found for file \"",
-                               r_file_name, "\", ",
-                              "so no corresponding test file will be made ",
-                              "for this file.")
+  not_making_message <- paste0(
+    "No examples found for file \"",
+    code(r_file_name), "\", ",
+    "so no corresponding test file will be made ",
+    "for this file."
+  )
   if (!length(exampless)) {
-    message(not_making_message)
+    pretty_msg(not_making_message)
     return(invisible(character(0)))
   }
-  test_shells <- mapply(make_test_shell, SIMPLIFY = FALSE,
-                        exampless, paste0("`", names(exampless), "()` works"),
-                        e_e = e_e)
+  test_shells <- mapply(make_test_shell,
+    SIMPLIFY = FALSE,
+    exampless, paste0("`", names(exampless), "()` works"),
+    e_e = e_e
+  )
   context <- r_file_name %>%
     filesstrings::before_last_dot() %>%
     filesstrings::str_split_camel_case() %>%
@@ -330,30 +422,47 @@ make_tests_shells_file <- function(r_file_name, pkg_dir = ".",
     paste() %>%
     stringr::str_replace_all("[-_]", " ") %T>% {
       if (nchar(.) > 0) {
-        . <- paste0(toupper(filesstrings::str_elem(., 1)),
-                    stringr::str_sub(., 2, -1))
+        . <- paste0(
+          toupper(filesstrings::str_elem(., 1)),
+          stringr::str_sub(., 2, -1)
+        )
       }
     }
-  combined <- c(paste0("context(\"", context, "\")"), "",
-                purrr::reduce(test_shells, ~ c(.x, "", .y)))
-  test_file_name <- paste0(rprojroot::find_package_root_file("tests"),
-                           "/testthat/test-",
-                           filesstrings::before_last_dot(r_file_name),
-                           "-examples") %>%
+  combined <- c(
+    paste0("context(\"", context, "\")"), "",
+    purrr::reduce(test_shells, ~c(.x, "", .y))
+  )
+  test_file_name <- paste0(
+    rprojroot::find_package_root_file("tests"),
+    "/testthat/test-",
+    filesstrings::before_last_dot(r_file_name),
+    "-examples"
+  ) %>%
     filesstrings::give_ext("R")
   if (!overwrite && file.exists(test_file_name)) {
-    stop ("Stopping as to proceed would be to overwrite an existing test file:",
-          " '", paste0("test_", r_file_name), "'. ", "\n",
-          "    * To proceed, rerun with overwrite = TRUE.")
+    stop(
+      "Stopping as to proceed would be to overwrite an existing test file:",
+      " '", paste0("test_", r_file_name), "'. ", "\n",
+      "    * To proceed, rerun with overwrite = TRUE."
+    )
+  }
+  if (!dir.exists(rprojroot::find_package_root_file("tests/testthat"))) {
+    usethis::use_testthat()
   }
-  if (!dir.exists(rprojroot::find_package_root_file("tests/testthat")))
-    devtools::use_testthat()
   readr::write_lines(combined, test_file_name)
+  grey_test_file_name <- test_file_name %>%
+    fs::path_rel(rprojroot::find_package_root_file()) %>%
+    code()
+  bulletize("Wrote {grey_test_file_name}.", done_bullet()) %>%
+    cat_line()
   if (open) file.edit(test_file_name)
+  bulletize("Complete the unit tests in {grey_test_file_name}.",
+            todo_bullet()) %>%
+    cat_line()
   invisible(combined)
 }
 
-#' @rdname test-shells
+#' @rdname make-test-shells
 #' @export
 make_tests_shells_pkg <- function(pkg_dir = ".", overwrite = FALSE,
                                   e_e = TRUE, open = FALSE, document = TRUE) {
@@ -362,11 +471,13 @@ make_tests_shells_pkg <- function(pkg_dir = ".", overwrite = FALSE,
   setwd(pkg_dir)
   pkg_root_dir <- try(rprojroot::find_root("DESCRIPTION"), silent = TRUE)
   if (inherits(pkg_root_dir, "try-error")) {
-    stop("Your package has no DESCRIPTION file.", "\n",
-         "    * Every R package must have a DESCRIPTION file ",
-         "in the root directory. ",
-         "Perhaps you specified the wrong `pkg_dir` in the argument to ",
-         "`extract_examples()`? The default is the current directory.")
+    stop(
+      "Your package has no DESCRIPTION file.", "\n",
+      "    * Every R package must have a DESCRIPTION file ",
+      "in the root directory. ",
+      "Perhaps you specified the wrong `pkg_dir` in the argument to ",
+      "`extract_examples()`? The default is the current directory."
+    )
   }
   setwd(pkg_root_dir)
   if (document) {
@@ -374,7 +485,9 @@ make_tests_shells_pkg <- function(pkg_dir = ".", overwrite = FALSE,
     invisible(utils::capture.output(devtools::document()))
   }
   list.files(path = rprojroot::find_package_root_file("R")) %>%
-    purrr::map(make_tests_shells_file, overwrite = overwrite, e_e = e_e,
-               open = open, document = FALSE) %>%
+    purrr::map(make_tests_shells_file,
+      overwrite = overwrite, e_e = e_e,
+      open = open, document = FALSE
+    ) %>%
     invisible()
 }
